@@ -13,24 +13,23 @@ from glob import glob
 from os.path import join as opj
 
 from datalad.core.local.repo import repo_from_path
-from datalad.tests.utils import (
-    with_tempfile,
+from datalad.distribution.create_test_dataset import _parse_spec
+from datalad.tests.utils_pytest import (
     assert_raises,
     assert_repo_status,
+    eq_,
     ok_,
+    with_tempfile,
 )
 from datalad.utils import (
+    chpwd,
     swallow_logs,
     swallow_outputs,
-    chpwd,
 )
-from datalad.distribution.create_test_dataset import _parse_spec
-
-from datalad.tests.utils import eq_
 
 
 @with_tempfile(mkdir=True)
-def test_create(outdir):
+def test_create(outdir=None):
     from datalad.api import create
     assert_raises(ValueError, create, outdir, description='Precious data', annex=False)
 
@@ -62,7 +61,7 @@ def test_create_1test_dataset():
 
 
 @with_tempfile(mkdir=True)
-def test_new_relpath(topdir):
+def test_new_relpath(topdir=None):
     from datalad.api import create_test_dataset
     with swallow_logs(), chpwd(topdir), swallow_outputs():
         dss = create_test_dataset('testds', spec='1')
@@ -73,7 +72,7 @@ def test_new_relpath(topdir):
 
 
 @with_tempfile()
-def test_hierarchy(topdir):
+def test_hierarchy(topdir=None):
     # GH 1178
     from datalad.api import create_test_dataset
     with swallow_logs(), swallow_outputs():
