@@ -1,5 +1,5 @@
 # emacs: -*- mode: python; py-indent-offset: 4; tab-width: 4; indent-tabs-mode: nil -*-
-# ex: set sts=4 ts=4 sw=4 noet:
+# ex: set sts=4 ts=4 sw=4 et:
 # ## ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 #
 #   See COPYING file distributed along with the datalad package for the
@@ -8,29 +8,32 @@
 # ## ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 """Tests for data providers"""
 
-import os.path as op
-
 import logging
-
+import os.path as op
 from unittest.mock import patch
 
-from ..providers import Provider
-from ..providers import Providers
-from ..providers import HTTPDownloader
-from ...utils import chpwd
-from ...utils import create_tree
-from ...tests.utils import assert_in
-from ...tests.utils import assert_false
-from ...tests.utils import assert_greater
-from ...tests.utils import assert_equal
-from ...tests.utils import assert_raises
-from ...tests.utils import ok_exists
-from ...tests.utils import swallow_logs
-from ...tests.utils import with_tempfile
-from ...tests.utils import with_tree
-from ...tests.utils import with_testsui
-
 from ...support.external_versions import external_versions
+from ...tests.utils_pytest import (
+    assert_equal,
+    assert_false,
+    assert_greater,
+    assert_in,
+    assert_raises,
+    ok_exists,
+    swallow_logs,
+    with_tempfile,
+    with_testsui,
+    with_tree,
+)
+from ...utils import (
+    chpwd,
+    create_tree,
+)
+from ..providers import (
+    HTTPDownloader,
+    Provider,
+    Providers,
+)
 
 
 def test_Providers_OnStockConfiguration():
@@ -84,7 +87,7 @@ def test_Providers_default_ones():
 
 
 def test_Providers_process_credential():
-    # If uknown type -- raises ValueError
+    # If unknown type -- raises ValueError
     assert_raises(ValueError, Providers._process_credential, 'cred', {'type': '_unknown_'})
 
 
@@ -97,30 +100,30 @@ def test_get_downloader_class():
     with patch.object(external_versions, '_versions', {'requests': None}):
         with assert_raises(RuntimeError) as cmr:
             Provider._get_downloader_class(url)
-        assert_in("you need 'requests'", str(cmr.exception))
+        assert_in("you need 'requests'", str(cmr.value))
 
 
 @with_tree(tree={
   'providers': {'atest.cfg':"""\
 [provider:syscrcns]
-url_re = https?://crcns\.org/.*
+url_re = https?://crcns\\.org/.*
 authentication_type = none
 """}})
 @with_tree(tree={
   'providers': {'atestwithothername.cfg':"""\
 [provider:usercrcns]
-url_re = https?://crcns\.org/.*
+url_re = https?://crcns\\.org/.*
 authentication_type = none
 """}})
 @with_tree(tree={
   '.datalad': {'providers': {'atest.cfg':"""\
 [provider:dscrcns]
-url_re = https?://crcns\.org/.*
+url_re = https?://crcns\\.org/.*
 authentication_type = none
 """}},
    '.git': { "HEAD" : ""}})
-@patch.multiple("appdirs.AppDirs", site_config_dir=None, user_config_dir=None)
-def test_Providers_from_config__files(sysdir, userdir, dsdir):
+@patch.multiple("platformdirs.AppDirs", site_config_dir=None, user_config_dir=None)
+def test_Providers_from_config__files(sysdir=None, userdir=None, dsdir=None):
     """Test configuration file precedence
 
     Ensure that provider precedence works in the correct order:
@@ -143,28 +146,28 @@ def test_Providers_from_config__files(sysdir, userdir, dsdir):
 
         # Test that the system defaults take precedence over the dataset
         # defaults (we're still within the dsdir)
-        with patch.multiple("appdirs.AppDirs", site_config_dir=sysdir, user_config_dir=None):
+        with patch.multiple("platformdirs.AppDirs", site_config_dir=sysdir, user_config_dir=None):
             providers = Providers.from_config_files(reload=True)
             provider = providers.get_provider('https://crcns.org/data....')
             assert_equal(provider.name, 'syscrcns')
 
         # Test that the user defaults take precedence over the system
         # defaults
-        with patch.multiple("appdirs.AppDirs", site_config_dir=sysdir, user_config_dir=userdir):
+        with patch.multiple("platformdirs.AppDirs", site_config_dir=sysdir, user_config_dir=userdir):
             providers = Providers.from_config_files(reload=True)
             provider = providers.get_provider('https://crcns.org/data....')
             assert_equal(provider.name, 'usercrcns')
 
 
 @with_tempfile(mkdir=True)
-def test_providers_enter_new(path):
-    with patch.multiple("appdirs.AppDirs", site_config_dir=None,
+def test_providers_enter_new(path=None):
+    with patch.multiple("platformdirs.AppDirs", site_config_dir=None,
                         user_config_dir=path):
         providers_dir = op.join(path, "providers")
         providers = Providers.from_config_files(reload=True)
 
         url = "blah://thing"
-        url_re = "blah:\/\/.*"
+        url_re = r"blah:\/\/.*"
         auth_type = "http_auth"
         creds = "user_password"
 
@@ -212,14 +215,14 @@ def test_providers_enter_new(path):
 
 @with_tree(tree={'providers.cfg': """\
 [provider:foo0]
-url_re = https?://foo\.org/.*
+url_re = https?://foo\\.org/.*
 authentication_type = none
 
 [provider:foo1]
-url_re = https?://foo\.org/.*
+url_re = https?://foo\\.org/.*
 authentication_type = none
 """})
-def test_providers_multiple_matches(path):
+def test_providers_multiple_matches(path=None):
     providers = Providers.from_config_files(
         files=[op.join(path, "providers.cfg")], reload=True)
     all_provs = providers.get_provider('https://foo.org/data',
@@ -232,14 +235,14 @@ def test_providers_multiple_matches(path):
 
 @with_tree(tree={'providers.cfg': """\
 [provider:foo0]
-url_re = https?://[foo-a\.org]/.*
+url_re = https?://[foo-a\\.org]/.*
 authentication_type = none
 
 [provider:foo1]
-url_re = https?://foo\.org/.*
+url_re = https?://foo\\.org/.*
 authentication_type = none
 """})
-def test_providers_badre(path):
+def test_providers_badre(path=None):
     """Test that a config with a bad regular expression doesn't crash
 
     Ensure that when a provider config has a bad url_re, there is no
