@@ -5,9 +5,9 @@ If there are git-annex'ed files already, git annex uninit and this procedure wil
 
 """
 
+from datalad import lgr
 from datalad.distribution.dataset import require_dataset
 from datalad.support.annexrepo import AnnexRepo
-from datalad import lgr
 
 
 def no_annex(ds):
@@ -34,9 +34,10 @@ def no_annex(ds):
         lgr.info("Creating and committing a .noannex file")
         noannex_file.touch()
         ds.save(noannex_file,
-                message="Added .noannex to prevent accidental initialization of git-annex")
+                message="Added .noannex to prevent accidental initialization of git-annex",
+                result_renderer='disabled')
 
 
 if __name__ == '__main__':
     import sys
-    no_annex(sys.argv[1])
\ No newline at end of file
+    no_annex(sys.argv[1])
