@@ -4,8 +4,8 @@ import logging
 import os
 import threading
 from abc import (
-    abstractmethod,
     ABCMeta,
+    abstractmethod,
 )
 from enum import Enum
 from queue import (
@@ -14,17 +14,17 @@ from queue import (
 )
 from subprocess import Popen
 from typing import (
-    Any,
     IO,
+    Any,
     Optional,
 )
-from datalad.utils import COPY_BUFSIZE
 
+from datalad.utils import COPY_BUFSIZE
 
 lgr = logging.getLogger("datalad.runner.runnerthreads")
 
 
-def _try_close(file_object: Optional[IO]):
+def _try_close(file_object: Optional[IO]) -> None:
     if file_object is not None:
         try:
             file_object.close()
@@ -40,21 +40,21 @@ class IOState(Enum):
 class SignalingThread(threading.Thread):
     def __init__(self,
                  identifier: str,
-                 signal_queues: list[Queue]
-                 ):
+                 signal_queues: list[Queue[tuple[Any, IOState, Optional[bytes]]]]
+                 ) -> None:
 
         super().__init__(daemon=True)
         self.identifier = identifier
         self.signal_queues = signal_queues
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return f"Thread<{self.identifier}>"
 
-    def __str__(self):
+    def __str__(self) -> str:
         return self.__repr__()
 
     def signal(self,
-               content: Any
+               content: tuple[Any, IOState, Optional[bytes]]
                ) -> bool:
         error_occurred = False
         for signal_queue in self.signal_queues:
@@ -73,9 +73,9 @@ class WaitThread(SignalingThread):
     """
     def __init__(self,
                  identifier: str,
-                 signal_queues: list[Queue],
+                 signal_queues: list[Queue[tuple[Any, IOState, Optional[bytes]]]],
                  process: Popen
-                 ):
+                 ) -> None:
         super().__init__(identifier, signal_queues)
         self.process = process
 
@@ -92,13 +92,13 @@ class WaitThread(SignalingThread):
 class ExitingThread(SignalingThread):
     def __init__(self,
                  identifier: str,
-                 signal_queues: list[Queue]
-                 ):
+                 signal_queues: list[Queue[tuple[Any, IOState, Optional[bytes]]]]
+                 ) -> None:
 
         super().__init__(identifier, signal_queues)
         self.exit_requested = False
 
-    def request_exit(self):
+    def request_exit(self) -> None:
         """
         Request the thread to exit. This is not guaranteed to
         have any effect, because the instance has to check for
@@ -111,9 +111,9 @@ class ExitingThread(SignalingThread):
 class TransportThread(ExitingThread, metaclass=ABCMeta):
     def __init__(self,
                  identifier: str,
-                 signal_queues: list[Queue],
+                 signal_queues: list[Queue[tuple[Any, IOState, Optional[bytes]]]],
                  user_info: Any
-                 ):
+                 ) -> None:
 
         super().__init__(identifier, signal_queues)
         self.user_info = user_info
@@ -186,12 +186,12 @@ class TransportThread(ExitingThread, metaclass=ABCMeta):
 class ReadThread(TransportThread):
     def __init__(self,
                  identifier: str,
-                 signal_queues: list[Queue],
+                 signal_queues: list[Queue[tuple[Any, IOState, Optional[bytes]]]],
                  user_info: Any,
                  source: IO,
-                 destination_queue: Queue,
+                 destination_queue: Queue[tuple[Any, IOState, bytes]],
                  length: int = COPY_BUFSIZE
-                 ):
+                 ) -> None:
 
         super().__init__(identifier, signal_queues, user_info)
         self.source = source
@@ -220,11 +220,11 @@ class ReadThread(TransportThread):
 class WriteThread(TransportThread):
     def __init__(self,
                  identifier: str,
-                 signal_queues: list[Queue],
+                 signal_queues: list[Queue[tuple[Any, IOState, Optional[bytes]]]],
                  user_info: Any,
-                 source_queue: Queue,
+                 source_queue: Queue[Optional[bytes]],
                  destination: IO
-                 ):
+                 ) -> None:
 
         super().__init__(identifier, signal_queues, user_info)
         self.source_queue = source_queue
