@@ -1,5 +1,5 @@
 # emacs: -*- mode: python; py-indent-offset: 4; tab-width: 4; indent-tabs-mode: nil -*-
-# ex: set sts=4 ts=4 sw=4 noet:
+# ex: set sts=4 ts=4 sw=4 et:
 # ## ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 #
 #   See COPYING file distributed along with the datalad package for the
@@ -185,8 +185,8 @@ class ActivityStats(object):
                 if o[0] != ' ':
                     out[i] = '  ' + o
             return ','.join(out).lstrip()
-            return "{files} files (git/annex: {add_git}/{add_annex}), " \
-                   "{skipped} skipped, {renamed} renamed, {overwritten} overwritten".format(
-                       **entries)
+            #return "{files} files (git/annex: {add_git}/{add_annex}), " \
+            #       "{skipped} skipped, {renamed} renamed, {overwritten} overwritten".format(
+            #           **entries)
         else:
             raise ValueError("Unknown mode %s" % mode)
